@@ -246,7 +246,7 @@ void ICalDirResource::retrieveCollections()
         c.setRights(rights);
     }
 
-    auto *attr = c.attribute<EntityDisplayAttribute>(Collection::AddIfMissing);
+    auto attr = c.attribute<EntityDisplayAttribute>(Collection::AddIfMissing);
     attr->setDisplayName(name() == identifier() ? i18n("Calendar Folder") : name());
     attr->setIconName(QStringLiteral("office-calendar"));
 
@@ -261,7 +261,7 @@ void ICalDirResource::retrieveItems(const Akonadi::Collection &)
     Item::List items;
     items.reserve(mIncidences.count());
 
-    for (const KCalendarCore::Incidence::Ptr &incidence : qAsConst(mIncidences)) {
+    for (const KCalendarCore::Incidence::Ptr &incidence : std::as_const(mIncidences)) {
         Item item;
         item.setRemoteId(incidence->instanceIdentifier());
         item.setMimeType(incidence->mimeType());
