@@ -54,7 +54,7 @@ void FolderMoveJob::davJobFinished(KJob *job)
         return;
     }
 
-    auto *davJob = qobject_cast<KIO::DavJob *>(job);
+    auto davJob = qobject_cast<KIO::DavJob *>(job);
 
     const QDomDocument document = davJob->response();
 
