@@ -13,7 +13,6 @@
 #include "settings.h"
 #include "settingsadaptor.h"
 
-// KDEPIMLIBS includes
 #include <Akonadi/KMime/SpecialMailCollections>
 #include <Akonadi/KMime/SpecialMailCollectionsRequestJob>
 #include <Collection>
@@ -22,8 +21,8 @@
 #include <MailTransport/ServerTest>
 #include <resourcesettings.h>
 
-// KDELIBS includes
 #include "pop3resource_debug.h"
+#include <KAuthorized>
 #include <KEMailSettings>
 #include <KMessageBox>
 #include <KUser>
@@ -77,11 +76,13 @@ void AccountWidget::setupWidgets()
 {
     auto mainLayout = new QVBoxLayout(this);
 
-    QWidget *page = new QWidget(this);
+    auto page = new QWidget(this);
     mainLayout->addWidget(page);
 
     setupUi(page);
 
+    passwordEdit->setRevealPasswordAvailable(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")));
+
     // only letters, digits, '-', '.', ':' (IPv6) and '_' (for Windows
     // compatibility) are allowed
     hostEdit->setValidator(&mValidator);
@@ -383,7 +384,7 @@ void AccountWidget::enablePopFeatures()
     }
 
     authCombo->clear();
-    for (int prot : qAsConst(supportedAuths)) {
+    for (int prot : std::as_const(supportedAuths)) {
         authCombo->addItem(Transport::authenticationTypeString(prot), prot);
     }
 
