@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_FILESTORE_COLLECTIONFETCHJOB_H
-#define AKONADI_FILESTORE_COLLECTIONFETCHJOB_H
+#pragma once
 
 #include "job.h"
 
@@ -28,7 +27,11 @@ class AKONADI_FILESTORE_EXPORT CollectionFetchJob : public Job
     Q_OBJECT
 
 public:
-    enum Type { Base, FirstLevel, Recursive };
+    enum Type {
+        Base,
+        FirstLevel,
+        Recursive,
+    };
 
     explicit CollectionFetchJob(const Collection &collection, Type type = FirstLevel, AbstractJobSession *session = nullptr);
 
@@ -59,4 +62,3 @@ private:
 }
 }
 
-#endif
