@@ -2,8 +2,7 @@
     SPDX-License-Identifier: BSD-2-Clause
 */
 
-#ifndef O1TIMEDREPLY_H
-#define O1TIMEDREPLY_H
+#pragma once
 
 #include <QNetworkReply>
 #include <QTimer>
@@ -27,4 +26,3 @@ private Q_SLOTS:
     void onTimeout();
 };
 
-#endif
